@@ -32,7 +32,12 @@ __all__ = (
     "GetRecommendationErrorTypeDef",
     "InstanceRecommendationOptionTypeDef",
     "InstanceRecommendationTypeDef",
+    "LambdaFunctionMemoryProjectedMetricTypeDef",
+    "LambdaFunctionMemoryRecommendationOptionTypeDef",
+    "LambdaFunctionRecommendationTypeDef",
+    "LambdaFunctionUtilizationMetricTypeDef",
     "ProjectedMetricTypeDef",
+    "ReasonCodeSummaryTypeDef",
     "RecommendationExportJobTypeDef",
     "RecommendationSourceTypeDef",
     "RecommendationSummaryTypeDef",
@@ -53,8 +58,10 @@ __all__ = (
     "GetEC2InstanceRecommendationsResponseTypeDef",
     "GetEC2RecommendationProjectedMetricsResponseTypeDef",
     "GetEnrollmentStatusResponseTypeDef",
+    "GetLambdaFunctionRecommendationsResponseTypeDef",
     "GetRecommendationSummariesResponseTypeDef",
     "JobFilterTypeDef",
+    "LambdaFunctionRecommendationFilterTypeDef",
     "S3DestinationConfigTypeDef",
     "UpdateEnrollmentStatusResponseTypeDef",
 )
@@ -143,6 +150,61 @@ InstanceRecommendationTypeDef = TypedDict(
     total=False,
 )
 
+LambdaFunctionMemoryProjectedMetricTypeDef = TypedDict(
+    "LambdaFunctionMemoryProjectedMetricTypeDef",
+    {
+        "name": Literal["Duration"],
+        "statistic": Literal["LowerBound", "UpperBound", "Expected"],
+        "value": float,
+    },
+    total=False,
+)
+
+LambdaFunctionMemoryRecommendationOptionTypeDef = TypedDict(
+    "LambdaFunctionMemoryRecommendationOptionTypeDef",
+    {
+        "rank": int,
+        "memorySize": int,
+        "projectedUtilizationMetrics": List["LambdaFunctionMemoryProjectedMetricTypeDef"],
+    },
+    total=False,
+)
+
+LambdaFunctionRecommendationTypeDef = TypedDict(
+    "LambdaFunctionRecommendationTypeDef",
+    {
+        "functionArn": str,
+        "functionVersion": str,
+        "accountId": str,
+        "currentMemorySize": int,
+        "numberOfInvocations": int,
+        "utilizationMetrics": List["LambdaFunctionUtilizationMetricTypeDef"],
+        "lookbackPeriodInDays": float,
+        "lastRefreshTimestamp": datetime,
+        "finding": Literal["Optimized", "NotOptimized", "Unavailable"],
+        "findingReasonCodes": List[
+            Literal[
+                "MemoryOverprovisioned",
+                "MemoryUnderprovisioned",
+                "InsufficientData",
+                "Inconclusive",
+            ]
+        ],
+        "memorySizeRecommendationOptions": List["LambdaFunctionMemoryRecommendationOptionTypeDef"],
+    },
+    total=False,
+)
+
+LambdaFunctionUtilizationMetricTypeDef = TypedDict(
+    "LambdaFunctionUtilizationMetricTypeDef",
+    {
+        "name": Literal["Duration", "Memory"],
+        "statistic": Literal["Maximum", "Average"],
+        "value": float,
+    },
+    total=False,
+)
+
 ProjectedMetricTypeDef = TypedDict(
     "ProjectedMetricTypeDef",
     {
@@ -160,6 +222,12 @@ ProjectedMetricTypeDef = TypedDict(
     total=False,
 )
 
+ReasonCodeSummaryTypeDef = TypedDict(
+    "ReasonCodeSummaryTypeDef",
+    {"name": Literal["MemoryOverprovisioned", "MemoryUnderprovisioned"], "value": float},
+    total=False,
+)
+
 RecommendationExportJobTypeDef = TypedDict(
     "RecommendationExportJobTypeDef",
     {
@@ -178,7 +246,9 @@ RecommendationSourceTypeDef = TypedDict(
     "RecommendationSourceTypeDef",
     {
         "recommendationSourceArn": str,
-        "recommendationSourceType": Literal["Ec2Instance", "AutoScalingGroup", "EbsVolume"],
+        "recommendationSourceType": Literal[
+            "Ec2Instance", "AutoScalingGroup", "EbsVolume", "LambdaFunction"
+        ],
     },
     total=False,
 )
@@ -187,7 +257,9 @@ RecommendationSummaryTypeDef = TypedDict(
     "RecommendationSummaryTypeDef",
     {
         "summaries": List["SummaryTypeDef"],
-        "recommendationResourceType": Literal["Ec2Instance", "AutoScalingGroup", "EbsVolume"],
+        "recommendationResourceType": Literal[
+            "Ec2Instance", "AutoScalingGroup", "EbsVolume", "LambdaFunction"
+        ],
         "accountId": str,
     },
     total=False,
@@ -212,6 +284,7 @@ SummaryTypeDef = TypedDict(
     {
         "name": Literal["Underprovisioned", "Overprovisioned", "Optimized", "NotOptimized"],
         "value": float,
+        "reasonCodeSummaries": List["ReasonCodeSummaryTypeDef"],
     },
     total=False,
 )
@@ -341,6 +414,15 @@ GetEnrollmentStatusResponseTypeDef = TypedDict(
     total=False,
 )
 
+GetLambdaFunctionRecommendationsResponseTypeDef = TypedDict(
+    "GetLambdaFunctionRecommendationsResponseTypeDef",
+    {
+        "nextToken": str,
+        "lambdaFunctionRecommendations": List["LambdaFunctionRecommendationTypeDef"],
+    },
+    total=False,
+)
+
 GetRecommendationSummariesResponseTypeDef = TypedDict(
     "GetRecommendationSummariesResponseTypeDef",
     {"nextToken": str, "recommendationSummaries": List["RecommendationSummaryTypeDef"]},
@@ -353,6 +435,12 @@ JobFilterTypeDef = TypedDict(
     total=False,
 )
 
+LambdaFunctionRecommendationFilterTypeDef = TypedDict(
+    "LambdaFunctionRecommendationFilterTypeDef",
+    {"name": Literal["Finding", "FindingReasonCode"], "values": List[str]},
+    total=False,
+)
+
 S3DestinationConfigTypeDef = TypedDict(
     "S3DestinationConfigTypeDef", {"bucket": str, "keyPrefix": str}, total=False
 )
